Struct mlua::prelude::LuaAnyUserData [−][src]
pub struct LuaAnyUserData<'lua>(_);
Handle to an internal Lua userdata for any type that implements UserData.
Similar to std::any::Any, this provides an interface for dynamic type checking via the is
and borrow methods.
Internally, instances are stored in a RefCell, to best match the mutable semantics of the Lua
language.
Note
This API should only be used when necessary. Implementing UserData already allows defining
methods which check the type and acquire a borrow behind the scenes.
Implementations
Borrow this userdata immutably if it is of type T.
Errors
Returns a UserDataBorrowError if the userdata is already mutably borrowed. Returns a
UserDataTypeMismatch if the userdata is not of type T.
Borrow this userdata mutably if it is of type T.
Errors
Returns a UserDataBorrowMutError if the userdata cannot be mutably borrowed.
Returns a UserDataTypeMismatch if the userdata is not of type T.
Sets an associated value to this AnyUserData.
The value may be any Lua value whatsoever, and can be retrieved with get_user_value.
As Lua < 5.3 allows to store only tables, the value will be stored in a table at index 1.
Returns an associated value set by set_user_value.
For Lua < 5.3 the value will be automatically extracted from the table wrapper from index 1.
Returns a metatable of this UserData.
Returned UserDataMetatable object wraps the original metatable and
provides safe access to its methods.
For T: UserData + 'static returned metatable is shared among all instances of type T.